==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridToolbarActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebGridToolbarActionsDescription } from "./WebGridToolbarActionsDescription";
/**
 * @hidden
 */
export let WebGridToolbarActionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarActionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarActionsDescriptionMetadata.a == null) {
                WebGridToolbarActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarActionsDescriptionMetadata.c(WebGridToolbarActionsDescriptionMetadata.a);
            }
            if (a.j(WebGridToolbarActionsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridToolbarActionsDescriptionMetadata.a);
        }
        static c(a) {
            WebGridToolbarContentDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarActions");
            a.item("__tagNameWC", "String:igc-grid-toolbar-actions");
            a.item("__packageNameWC", "String:grids");
            a.item("Actions", "Collection:WebGridToolbarBaseAction:WebGridToolbarBaseActionCollection:WebGridToolbarBaseAction");
            a.item("Name", "String");
        }
        static d(a) {
            WebGridToolbarActionsDescriptionMetadata.b(a);
            a.aa("WebGridToolbarActions", () => new WebGridToolbarActionsDescription());
            a.z("WebGridToolbarActions", WebGridToolbarActionsDescriptionMetadata.a);
        }
    }
    WebGridToolbarActionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarActionsDescriptionMetadata, 'WebGridToolbarActionsDescriptionMetadata');
    WebGridToolbarActionsDescriptionMetadata.a = null;
    return WebGridToolbarActionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridToolbarActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebGridToolbarActionsDescription } from "./WebGridToolbarActionsDescription";
/**
 * @hidden
 */
export let WebGridToolbarActionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarActionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarActionsDescriptionMetadata.a == null) {
                WebGridToolbarActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarActionsDescriptionMetadata.c(WebGridToolbarActionsDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarActionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridToolbarActionsDescriptionMetadata.a);
        }
        static c(a) {
            WebGridToolbarContentDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarActions");
            a.item("__tagNameWC", "String:igc-grid-toolbar-actions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("Actions", "Collection:WebGridToolbarBaseAction:WebGridToolbarBaseActionCollection:WebGridToolbarBaseAction");
            a.item("Name", "String");
        }
        static d(a) {
            WebGridToolbarActionsDescriptionMetadata.b(a);
            a.ac("WebGridToolbarActions", () => new WebGridToolbarActionsDescription());
            a.ab("WebGridToolbarActions", WebGridToolbarActionsDescriptionMetadata.a);
        }
    }
    WebGridToolbarActionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarActionsDescriptionMetadata, 'WebGridToolbarActionsDescriptionMetadata');
    WebGridToolbarActionsDescriptionMetadata.a = null;
    return WebGridToolbarActionsDescriptionMetadata;
})();
